==> dinolib-0.9.0.tar.gz: dinolib-0.9.0/lib/form/of_text.inc.php <==
<?php
/* OOHForms: text
 *
 * Copyright (c) 1998 by Jay Bloodworth
 * This file is modified by Dino Co.,Ltd .
 *
 * $Id: of_text.inc.php,v 1.4 2003/03/13 14:34:12 noriko Exp $
 */


/**
 * OOHForms: text
 *
 *
 * @package Dino_Form
 * @access public
 */

class of_text extends of_element {

  var $maxlength;
  var $minlength;
  var $length_e;
  var $valid_regex;
  var $valid_icase;
  var $valid_e;
  var $pass;
  var $size;

  // Constructor
  function of_text($a) {
    $this->setup_element($a);
    if ($a["type"]=="password")
      $this->pass=1;
  }

  function self_get($val,$which, &$count) {
    $str = "";
    
    if (is_array($this->value))
      $v = htmlspecialchars($this->value[$which]);
    else 
      $v = htmlspecialchars($this->value, ENT_QUOTES);
    $n = $this->name . ($this->multiple ? "[]" : "");
    $str .= "<input name='$n' value=\"$v\"";
    $str .= ($this->pass)? " type='password'" : " type='text'";
    if ($this->maxlength)
      $str .= " maxlength='$this->maxlength'";
    if ($this->size) 
      $str .= " size='$this->size'";
    if ($this->extrahtml) 
      $str .= " $this->extrahtml";
    $str .= ">";
    
    $count = 1;
    return $str;
  }

  function self_get_frozen($val,$which, &$count) {
    $str = "";
    
    if (is_array($this->value))
      $v = $this->value[$which];
    else 
      $v = $this->value;
    $n = $this->name . ($this->multiple ? "[]" : "");
//    $v = str_replace('"', '&quot;', $v);
    $v = htmlspecialchars($v, ENT_QUOTES);
    $str .= "<input type='hidden' name='$n' value=\"$v\">\n";
    // $str .= "<table border=1><tr><td>$v</td></tr></table>\n";
    $str .= $v."\n";
    
    $count = 1;
    return $str;
  }

  function self_get_js($ndx_array) {
    $str = "";
    $i = 0;

    if(!$ndx_array){ return; }

    reset($ndx_array);
    while (list($k,$n) = each($ndx_array)) {
      $n = $this->name;
      if ($this->length_e) {
	$str .= "if (f.elements['${n}'].value.length < $this->minlength) {\n";
	$str .= "  alert(\"$this->length_e\");\n";
	$str .= "  f.elements['${n}'].focus();\n";
	$str .= "  return(false);\n}\n";
      }
      if ($this->valid_e) {
	$flags = ($this->icase ? "gi" : "g");
	$str .= "if (window.RegExp) {\n";
	$str .= "  var reg = new RegExp(\"$this->valid_regex\",\"$flags\");\n";
	$str .= "  if (!reg.test(f.elements['${n}'].value)) {\n";
	$str .= "    alert(\"$this->valid_e\");\n";
	$str .= "    f.elements['${n}'].focus();\n";
	$str .= "    return(false);\n";
	$str .= "  }\n}\n";
      }
      $i++;
    }
    return $str;
  }

  function self_validate($val) {
    if (!is_array($val)) $val = array($val);
    reset($val);
    while (list($k,$v) = each($val)) {
      if ($this->length_e && (strlen($v) < $this->minlength))
        return $this->length_e;
      if ($this->valid_e && (($this->icase && 
            !eregi($this->valid_regex,$v)) ||
           (!$this->icase &&
            !ereg($this->valid_regex,$v))))
        return $this->valid_e;
    }
    return false;
  } 

} // end TEXT

?>

==> dinolib-0.9.3.tar.gz: dinolib-0.9.3/lib/form/of_text.inc.php <==
<?php
/* OOHForms: text
 *
 * Copyright (c) 1998 by Jay Bloodworth
 * This file is modified by Dino Co.,Ltd .
 *
 * $Id: of_text.inc.php,v 1.5 2003/04/20 12:02:59 tumf Exp $
 */


/**
 * OOHForms: text
 *
 *
 * @package Dino_Form
 * @access public
 */

class of_text extends of_element {

  var $maxlength;
  var $minlength;
  var $length_e;
  var $valid_regex;
  var $valid_icase;
  var $valid_e;
  var $pass;
  var $size;

  // Constructor
  function of_text($a) {
    $this->setup_element($a);
    if ($a["type"]=="password")
      $this->pass=1;
  }

  function self_get($val,$which, &$count) {
    $str = "";
    
    if (is_array($this->value))
      $v = htmlspecialchars($this->value[$which]);
    else 
      $v = htmlspecialchars($this->value, ENT_QUOTES);
    $n = $this->name . ($this->multiple ? "[]" : "");
    $str .= "<input name='$n' value=\"$v\"";
    $str .= ($this->pass)? " type='password'" : " type='text'";
    if ($this->maxlength)
      $str .= " maxlength='$this->maxlength'";
    if ($this->size) 
      $str .= " size='$this->size'";
    if ($this->extrahtml) 
      $str .= " $this->extrahtml";
    $str .= ">";
    
    $count = 1;
    return $str;
  }

  function self_get_frozen($val,$which, &$count) {
    $str = "";
    if (is_array($this->value))
      $v = $this->value[$which];
    else 
      $v = $this->value;


    $n = $this->name . ($this->multiple ? "[]" : "");
//    $v = str_replace('"', '&quot;', $v);
    $v = htmlspecialchars($v, ENT_QUOTES);
    $str .= "<input type='hidden' name='$n' value=\"$v\" />\n";
    // $str .= "<table border=1><tr><td>$v</td></tr></table>\n";
    if($this->pass){
      $str .= "***********";
    }else{
      $str .= $v;
    }
    $str .="\n";
    $count = 1;
    return $str;
  }

  function self_get_js($ndx_array) {
    $str = "";
    $i = 0;

    if(!$ndx_array){ return; }

    reset($ndx_array);
    while (list($k,$n) = each($ndx_array)) {
      $n = $this->name;
      if ($this->length_e) {
	$str .= "if (f.elements['${n}'].value.length < $this->minlength) {\n";
	$str .= "  alert(\"$this->length_e\");\n";
	$str .= "  f.elements['${n}'].focus();\n";
	$str .= "  return(false);\n}\n";
      }
      if ($this->valid_e) {
	$flags = ($this->icase ? "gi" : "g");
	$str .= "if (window.RegExp) {\n";
	$str .= "  var reg = new RegExp(\"$this->valid_regex\",\"$flags\");\n";
	$str .= "  if (!reg.test(f.elements['${n}'].value)) {\n";
	$str .= "    alert(\"$this->valid_e\");\n";
	$str .= "    f.elements['${n}'].focus();\n";
	$str .= "    return(false);\n";
	$str .= "  }\n}\n";
      }
      $i++;
    }
    return $str;
  }

  function self_validate($val) {
    if (!is_array($val)) $val = array($val);
    reset($val);
    while (list($k,$v) = each($val)) {
      if ($this->length_e && (strlen($v) < $this->minlength))
        return $this->length_e;
      if ($this->valid_e && (($this->icase && 
            !eregi($this->valid_regex,$v)) ||
           (!$this->icase &&
            !ereg($this->valid_regex,$v))))
        return $this->valid_e;
    }
    return false;
  } 

} // end TEXT

?>
